/*
 *   kgoodstuff - a button bar a la FvwmButtons for KDE
 *   Copyright (C) 1998  Juergen Vigna
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdlib.h>
#include <kapp.h>
#include "prefglob.h"

#define Inherited PreferencesGlobData

PreferencesGlob::PreferencesGlob(QWidget* parent,const char* name)
	:Inherited( parent, name )
{
    labelIconPath->setAutoResize(true);
    labelMaxXY->setAutoResize(true);
    labelPosX->setAutoResize(true);
    labelPosY->setAutoResize(true);
    labelIconPath->setText(i18n("Icon Path:"));
    labelMaxXY->setText(i18n("MaxXY:"));
    labelMinXY->setText(i18n("MinXY:"));
    labelPosX->setText(i18n("PosX:"));
    labelPosY->setText(i18n("PosY:"));
    checkOrientation->setText(i18n("Horiz. Orientation"));
    lableEnterRaise->setText(i18n("Raise delay:"));
    lableLeaveLower->setText(i18n("Lower delay:"));
    okButton->setText(i18n("&OK"));
    applyButton->setText(i18n("&Apply"));
    cancelButton->setText(i18n("&Cancel"));
    setLabelRC();
    setPos(labelIconPath,iconPath);
    setPos(labelMaxXY,maxXY);
    setPos(labelMinXY,minXY);
    setPos(labelPosX,posX);
    setPos(labelPosY,posY);
    setPos(lableEnterRaise,inputEnterRaise);
    setPos(lableLeaveLower,inputLeaveLower);
    pokButton = okButton;
}


PreferencesGlob::~PreferencesGlob()
{
}

void PreferencesGlob::setPrefs(const char *iconpath, const char *maxxy,
                               const char *minxy, const char *posx,
                               const char *posy, bool or, int nc,
                               int eraise, int llower)
{
    QString
        str;
    
    iconPath->setText(iconpath);
    maxXY->setText(maxxy);
    minXY->setText(minxy);
    posX->setText(posx);
    posY->setText(posy);
    str.sprintf("%d",nc);
    nColumns->setText(str);
    checkOrientation->setChecked(or);
    str.sprintf("%d",eraise);
    inputEnterRaise->setText(str);
    str.sprintf("%d",llower);
    inputLeaveLower->setText(str);
    setLabelRC();
}

const char *PreferencesGlob::getIconPath()
{
    static QString
        str;

    str = iconPath->text();
    if (str.isEmpty())
        return "";
    if (str.right(1) != ":")
        str += ":";
    return str.data();
}

const char *PreferencesGlob::getMaxXY()
{
    QString
        str = maxXY->text();
    bool
        ok;
    
    (void)str.toInt(&ok);
    if (ok)
        return maxXY->text();
    return 0;
}

const char *PreferencesGlob::getMinXY()
{
    QString
        str = minXY->text();
    bool
        ok;
    
    (void)str.toInt(&ok);
    if (ok)
        return minXY->text();
    return 0;
}

const char *PreferencesGlob::getPosX()
{
    QString
        str = posX->text();
    bool
        ok;
    
    (void)str.toInt(&ok);
    if (ok)
        return posX->text();
    return 0;
}

const char *PreferencesGlob::getPosY()
{
    QString
        str = posY->text();
    bool
        ok;
    
    (void)str.toInt(&ok);
    if (ok)
        return posY->text();
    return 0;
}

bool PreferencesGlob::getHOrient()
{
    return checkOrientation->isChecked();
}

int PreferencesGlob::getERaise()
{
    QString
        str = inputEnterRaise->text();
    int
        ok;
    
    ok = str.toInt();
    if (ok > 0)
        return ok;
    else if (ok < 0)
        return -ok;
    return 0;
}

int PreferencesGlob::getLLower()
{
    QString
        str = inputLeaveLower->text();
    int
        ok;
    
    ok = str.toInt();
    if (ok > 0)
        return ok;
    else if (ok < 0)
        return -ok;
    return 0;
}

int PreferencesGlob::getNColumns()
{
    QString
        str = nColumns->text();
    int
        ok;
    
    ok = str.toInt();
    if (ok > 0)
        return ok;
    else if (ok < 0)
        return -ok;
    return 1;
}

void PreferencesGlob::setPos(QLabel *lab, QLineEdit *le)
{
    int pos, diff;

    pos = lab->x() + lab->width() + 5;
    diff = pos - le->x();
    if (diff > 0)
        le->setGeometry(pos, le->y(), le->width() - diff, le->height());
}

void PreferencesGlob::okButtonCB()
{
    hide();
    emit okButtonPressed();
}

void PreferencesGlob::applyButtonCB()
{
    emit okButtonPressed();
}

void PreferencesGlob::setLabelRC()
{
    if (checkOrientation->isChecked())
        labelRC->setText(i18n("Rows:"));
    else
        labelRC->setText(i18n("Columns:"));
    setPos(labelRC,nColumns);
}

void PreferencesGlob::toggledHOrient(bool)
{
    setLabelRC();
}
